# Recipes

This section contains recipes for common Harbor API use cases that go beyond the basics by combining multiple API endpoints, or adding additional functionality such as concurrency.

Most recipes make use of the `harborapi.ext` module which provides additional functionality for common tasks such as concurrency and aggregation of multiple API calls. For more information on the `harborapi.ext` module, see the [Extended functionality](../usage/ext) page.

For the individual spec-compliant Harbor API endpoints, see [Endpoints](/endpoints)
